Description Usage Arguments Value
DEPRECATED, please see package datamods for similar features.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | chooseDataUI(id, label = "Data", icon = "database", width = "100%", ...)
chooseDataServer(
input,
output,
session,
dataModule = c("GlobalEnv", "ImportFile"),
data = NULL,
name = NULL,
selectVars = TRUE,
selectedTypes = c("continuous", "discrete", "time"),
coerceVars = FALSE,
launchOnStart = TRUE,
size = "m"
)
|
id |
Module's id. |
label |
Label for button, passed to |
icon |
Icon to appears on the button, passed to |
width |
Width of button, passed to |
... |
Other arguments passed to |
input, output, session |
standards |
dataModule |
Data module to use, choose between |
data |
A |
name |
Character, object's name to use for |
selectVars |
Display module to select variables, |
selectedTypes |
Type of variables selected by default in select variables module.
Possible types are |
coerceVars |
Display module to coerce variables between different class, |
launchOnStart |
Opens modal window when the application starts. |
size |
Size for the modal window. |
a reactiveValues containing the data selected under slot data
and the name of the selected data.frame under slot name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.